import type { CustomEmoji } from "./custom_emoji";

	export interface Account {
	  id: string;
	  /** Username, not including domain */
	  username: string;
	  /** Webfinger account URI */
	  acct: string;
	  /** The user's profile page */
	  url: string;
	  /** The user's nickname/display name */
	  display_name: string;
	  /** The user's bio */
	  note: string;
	  /** The user's avatar URL */
	  avatar: string;
	  /** The user's avatar URL as a static image. Same as `avatar` if the avatar is not animated */
	  avatar_static: string;
	  /** The user's header URL */
	  header: string;
	  /** The user's header URL as a static image. Same as `header` if the header is not animated */
	  header_static: string;
	  /** Whether the account manually approves follow requests */
	  locked: boolean;
	  /** Additional metadata attached to a profile as name-value pairs */
	  fields: Field[];
	  /** Custom emoji entities to be used when rendering the profile */
	  emojis: CustomEmoji[];
	  /** Indicates that the account may perform automated actions, may not be monitored, or identifies as a robot */
	  bot: boolean;
	  /** When the account was created */
	  created_at: string;
	  /** When the most recent status was posted */
	  last_status_at: string | null;
	  /** How many statuses are attached to this account */
	  statuses_count: number;
	  /** The reported followers of this profile */
	  followers_count: number;
	  /** The reported follows of this profile */
	  following_count: number;
	}

	export interface Field {
  /** The key of a given field’s key-value pair */
	  name: string;
	  /** The value associated with the name key */
	  value: string;
	}
